@@ -49,7 +49,7 @@ class DolphinDBKernel(Kernel):
             username = code_list[3]
             password = code_list[4]
             enableSSL = code_list[5]
-            s = ddb.session(enableSSL=enableSSL)
+            self.s = ddb.session(enableSSL=(enableSSL=='true'))
             self.connect(server, port, username, password)
             if code.startswith('connect-to-ddb-new'):
                 bytes_password = password.encode()
